netapp_ontap.models.rfc2307bis API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.rfc2307bis`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class Rfc2307bisSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Rfc2307bis object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET PATCH`

    Indicates whether RFC 2307bis is enabled for the client schema.

    Example: false

  `group_of_unique_names: str GET PATCH`

    RFC 2307bis groupOfUniqueNames object class.

    Example: groupOfUniqueNames

  `maximum_groups: Size GET PATCH`

    Maximum number of groups supported when RFC 2307bis is enabled.

    Example: 256

  `unique_member: str GET PATCH`

    RFC 2307bis uniqueMember attribute.

    Example: uniqueMember